function r=plrow(zs,zg,dz,dx,nz,nx)

% computes row of path length matrix corresponding to 
% single source-receiver pair

xs=0;
xg=nx*dx;

nc=nz*nx;
r=zeros(1,nc);
c=zeros(2,2);

% rules: sources and geophones may not live on the same
% side, but may be at the same depth;
% if source and geophone depths coincide with top or
% bottom of cell, divided equally between cell and
% upper or lower neighbor
% source and geophone depths must lie strictly inside
% model depth range

if zs<=0 | zs>=nz*dz | zg<=0 | zg>=nz*dz
  error('Error: plrow - source or geophone depth out of range')
end

for i=1:nz
  for j=1:nx
    n=0;
    zt=(i-1)*dz;
    zb=i*dz;
    xl=(j-1)*dx;
    xr=j*dx;
% find intersection with top, if any
    zi=zt;
    if zg-zs ~= 0
      t=(zi-zs)/(zg-zs);
      xi=xs+t*(xg-xs);
      if xl < xi & xi < xr
        n=n+1;
        c(1,n)=zi;
        c(2,n)=xi;
      end
    else
      if zi==zg
        n=2;
        c(1,1)=zi;
        c(2,1)=0.5*xl;
        c(1,2)=zi;
        c(2,2)=0.5*xr;
      end
    end
% find intersection with bottom, if any
    if n<2 
      zi=zb;
      if zg-zs ~= 0
        t=(zi-zs)/(zg-zs);
        xi=xs+t*(xg-xs);
        if xl < xi & xi < xr
          n=n+1;
          c(1,n)=zi;
          c(2,n)=xi;
        end
      else
        if zi==zg
          n=2;
          c(1,1)=zi;
          c(2,1)=0.5*xl;
          c(1,2)=zi;
          c(2,2)=0.5*xr;
        end
      end
    end
% find intersection with left side, if any
    if n<2 
      xi=xl;
      t=(xi-xs)/(xg-xs);
      zi=zs+t*(zg-zs);
      if zt <= zi & zi <= zb
        n=n+1;
        c(1,n)=zi;
        c(2,n)=xi;
      end
    end
% find intersection with right side if any
    if n<2 
      xi=xr;
      t=(xi-xs)/(xg-xs);
      zi=zs+t*(zg-zs);
      if zt <= zi & zi <= zb
        n=n+1;
        c(1,n)=zi;
        c(2,n)=xi;
      end
    end
% if n=2, compute ray path length, store
    if n==2
      r((j-1)*nz+i)=sqrt((c(1,1)-c(1,2))^2 +(c(2,1)-c(2,2))^2);
    end
  end
end







