function [tt,dz]=riem1(velname,theta,x0,zf,nx,dx,ox)

% Riemann problem solver for eikonal equation in 2D
% computes traveltime field and x- partial derivatives
% at datum depth z_d, for point source on initial depth level
% z_0, offset x_0. Uses aperture theta (degrees) from vertical
% to ensure successful depth step. Substeps when necessary to 
% maintain stability. 

cfl=0.8;
tol=1.0e-8;
rad=pi*theta/180.0;
eps=cos(rad);
ceps=sin(rad);

dz=cfl*dx*min(cot(rad),1);
nz=1+round(zf/dz);
ix0=1+round((x0-ox)/dx);

if ix0 < 1
   fprintf('Error: RIEMANN\n')
   fprintf('   x0 = %g not in [%g, %g]\n',x0,ox,ox+(nx-1)*dx)
   exit
end

if ix0 > nx
   fprintf('Error: RIEMANN\n')
   fprintf('   x0 = %g not in [%g, %g]\n',x0,ox,ox+(nx-1)*dx)
   exit
end

tt=zeros(nz,nx);
zc=dz*(0:nz-1)';
xc=ox*ones(nx,1)+dx*(0:nx-1)';
zz=zc*ones(1,nx);
xx=ones(nz,1)*xc';
[v,vz,vx]=feval(velname,zz,xx);
ss=ones(nz,nx)./(v.*v);

% initialize with traveltime along z=0
tt(1,1:ix0-1)=fliplr(cumsum(fliplr(sqrt(ss(1,1:ix0-1))*dx)));
tt(1,ix0+1:nx)=cumsum(sqrt(ss(1,ix0+1:nx))*dx);

for i=1:nz-1
   fprintf(' step %g\n',i)
   tt(i+1,:)=tt(i,:)+dz*ham1(theta,ss(i,:),tt(i,:),dx);
end


